@@ -28,7 +28,13 @@ def unix_seconds_to_datetime(value):
 
 class SchemaMismatch(Exception):
     def __init__(self, errors):
-        msg = "Errors during transform\n\t{}".format("\n\t".join(e.tostr() for e in errors))
+        if not errors:
+            msg = "An error occured during transform that was not a schema mismatch"
+
+        else:
+            msg = "Errors during transform\n\t{}".format("\n\t".join(e.tostr() for e in errors))
+            msg += "\nErrors during transform: [{}]".format(", ".join(e.tostr() for e in errors))
+
         super(SchemaMismatch, self).__init__(msg)
 
 
@@ -52,12 +58,13 @@ class Transformer:
     def __init__(self, integer_datetime_fmt=NO_INTEGER_DATETIME_PARSING, pre_hook=None):
         self.integer_datetime_fmt = integer_datetime_fmt
         self.pre_hook = pre_hook
-        self._errors = []
+        self.removed = set()
+        self.errors = []
 
     def transform(self, data, schema):
         success, transformed_data = self.transform_recur(data, schema, [])
         if not success:
-            raise SchemaMismatch(self._errors)
+            raise SchemaMismatch(self.errors)
 
         return transformed_data
 
@@ -81,15 +88,13 @@ class Transformer:
                     return success, transformed_data
                 else:
                     if i == (types_len - 1):
-                        if "object" not in types and "array" not in types:
-                            self._errors.append(Error(path, data, schema))
+                        self.errors.append(Error(path, data, schema))
                         return False, None
                     else:
                         pass
             except:
                 if i == (types_len - 1):
-                    if "object" not in types and "array" not in types:
-                        self._errors.append(Error(path, data, schema))
+                    self.errors.append(Error(path, data, schema))
                     return False, None
                 else:
                     pass
@@ -116,8 +121,8 @@ class Transformer:
                 successes.append(success)
                 result[key] = subdata
             else:
-                # Pass on fields not in schema
-                result[key] = value
+                # track that field has been removed
+                self.removed.add(".".join(path + [key]))
 
         return all(successes), result
 
@@ -213,3 +218,8 @@ def transform(data, schema, integer_datetime_fmt=NO_INTEGER_DATETIME_PARSING, pr
     """
     transformer = Transformer(integer_datetime_fmt, pre_hook)
     return transformer.transform(data, schema)
+
+
+def _transform_datetime(value, integer_datetime_fmt=NO_INTEGER_DATETIME_PARSING):
+    transformer = Transformer(integer_datetime_fmt)
+    return transformer._transform_datetime(value)
