@@ -2,6 +2,7 @@ import unittest
 from singer import transform
 from singer.transform import *
 
+
 class TestTransform(unittest.TestCase):
     def test_integer_transform(self):
         schema = {'type': 'integer'}
@@ -19,7 +20,7 @@ class TestTransform(unittest.TestCase):
                                                                      'amount': {'type': 'integer'}}}}}}
         data = {'addrs': [{'amount': '123'}, {'amount': '456'}]}
         expected = {'addrs': [{'amount': 123}, {'amount': 456}]}
-        self.assertEqual(expected, transform(data, schema))
+        self.assertDictEqual(expected, transform(data, schema))
 
     def test_null_transform(self):
         self.assertEqual('', transform('', {'type': ['null', 'string']}))
@@ -48,48 +49,89 @@ class TestTransform(unittest.TestCase):
         schema = {'anyOf': [{'type': 'null'}, {'format': 'date-time', 'type': 'string'}]}
         string_datetime = '2016-03-10T18:47:20Z'
         self.assertEqual(string_datetime, transform(string_datetime, schema))
-        self.assertEqual(None, transform(None, schema))
+        self.assertIsNone(transform(None, schema))
 
     def test_error_path(self):
         schema = {"type": "object",
                   "properties": {"foo": {"type": "integer"},
                                  "baz": {"type": "integer"}}}
         data = {"foo": "bar", "baz": 1}
-        self.assertEqual((False, None, [], [['foo']]), transform_recur(data, schema, NO_INTEGER_DATETIME_PARSING, [], []))
+        trans = Transformer(NO_INTEGER_DATETIME_PARSING)
+        success, data = trans.transform_recur(data, schema, [])
+        self.assertFalse(success)
+        self.assertIsNone(data)
+        self.assertListEqual([["foo"]], sorted(e.path for e in trans._errors))
 
     def test_nested_error_path_throws(self):
-        schema = {"type": "object",
-                  "properties": {"key1": {"type": "object",
-                                          "properties": {"key2": {"type": "object",
-                                                                  "properties": {"key3": {"type": "object",
-                                                                                          "properties": {"key4": {"type": "integer"}}}}}}}}}
+        schema = {
+            "type": "object",
+            "properties": {
+                "key1": {
+                    "type": "object",
+                    "properties": {
+                        "key2": {
+                            "type": "object",
+                            "properties": {
+                                "key3": {
+                                    "type": "object",
+                                    "properties": {
+                                        "key4": {"type": "integer"},
+                                    },
+                                },
+                            },
+                        },
+                    },
+                },
+            },
+        }
         data = {"key1": {"key2": {"key3": {"key4": "not an integer"}}}}
-        self.assertEqual((False, None, [], [['key1', 'key2', 'key3', 'key4']]),
-                         transform_recur(data, schema, NO_INTEGER_DATETIME_PARSING, [], []))
+        trans = Transformer()
+        success, _ = trans.transform_recur(data, schema, [])
+        self.assertFalse(success)
+        self.assertListEqual([['key1', 'key2', 'key3', 'key4']], sorted(e.path for e in trans._errors))
 
     def test_nested_error_path_no_throw(self):
-        schema = {"type": "object",
-                  "properties": {"key1": {"type": "object",
-                                          "properties": {"key2": {"type": "object",
-                                                                  "properties": {"key3": {"type": "object",
-                                                                                          "properties": {"key4": {"type": "string"},
-                                                                                                         "key5": {"type": "string"}}}}}}}}}
+        schema = {
+            "type": "object",
+            "properties": {
+                "key1": {
+                    "type": "object",
+                    "properties": {
+                        "key2": {
+                            "type": "object",
+                            "properties": {
+                                "key3": {
+                                    "type": "object",
+                                    "properties": {
+                                        "key4": {"type": "string"},
+                                        "key5": {"type": "string"},
+                                    },
+                                },
+                            },
+                        },
+                    },
+                },
+            },
+        }
         data = {"key1": {"key2": {"key3": {"key4": None, "key5": None}}}}
-        success, data, _, error_paths = transform_recur(data, schema, NO_INTEGER_DATETIME_PARSING, [], [])
-        self.assertEqual(False, success)
-        self.assertEqual(None, data)
+        trans = Transformer()
+        success, data = trans.transform_recur(data, schema, [])
+        self.assertFalse(success)
+        self.assertIsNone(data)
         # NB> error_paths may be returned in any order, so we sort here to be deterministic
-        self.assertEqual(sorted(error_paths), sorted([['key1', 'key2', 'key3', 'key4'], ['key1', 'key2', 'key3', 'key5']]))
+        self.assertListEqual([['key1', 'key2', 'key3', 'key4'], ['key1', 'key2', 'key3', 'key5']],
+                             sorted(e.path for e in trans._errors))
 
     def test_error_path_array(self):
         schema =  {"type": "object",
                    "properties": {"integers": {"type": "array",
                                                "items": {"type": "integer"}}}}
         data = {"integers": [1, 2, "not an integer", 4, "also not an integer"]}
-        success, _, _, error_paths = transform_recur(data, schema, NO_INTEGER_DATETIME_PARSING, [], [])
-        self.assertEqual(False, success)
+        trans = Transformer()
+        success, data = trans.transform_recur(data, schema, [])
+        self.assertFalse(success)
         # NB> error_paths may be returned in any order, so we sort here to be deterministic
-        self.assertEqual(sorted(error_paths), sorted([["integers", 2], ["integers", 4]]))
+        self.assertListEqual([["integers", 2], ["integers", 4]], sorted(e.path for e in trans._errors))
 
     def test_nested_error_path_array(self):
         schema =  {"type": "object",
@@ -97,10 +139,12 @@ class TestTransform(unittest.TestCase):
                                                         "items": {"type": "array",
                                                                   "items": {"type": "integer"}}}}}
         data = {"lists_of_integers": [[1, "not an integer"], [2, 3], ["also not an integer", 4]]}
-        success, _, _, error_paths = transform_recur(data, schema, NO_INTEGER_DATETIME_PARSING, [], [])
-        self.assertEqual(False, success)
-        # NB> error_paths may be returned in any order, so we sort here to be deterministic
-        self.assertEqual(sorted(error_paths), sorted([["lists_of_integers", 0, 1], ["lists_of_integers", 2, 0]]))
+        trans = Transformer()
+        success, transformed_data = trans.transform_recur(data, schema, [])
+        self.assertFalse(success)
+        self.assertListEqual(
+            [["lists_of_integers", 0, 1], ["lists_of_integers", 2, 0]],
+            sorted(e.path for e in trans._errors))
 
     def test_error_path_datetime(self):
         schema = {"type": "object",
@@ -110,15 +154,17 @@ class TestTransform(unittest.TestCase):
         data = {"good_datetime": "2017-04-11T16:07:00Z",
                 "bad_datetime1": "not a datetime",
                 "bad_datetime2": 1}
-        success, _, _, error_paths = transform_recur(data, schema, NO_INTEGER_DATETIME_PARSING, [], [])
-        self.assertEqual(False, success)
-        self.assertEqual(sorted(error_paths), sorted([['bad_datetime1'], ['bad_datetime2']]))
+        trans = Transformer()
+        success, transformed_data = trans.transform_recur(data, schema, [])
+        self.assertFalse(success)
+        self.assertListEqual([["bad_datetime1"], ["bad_datetime2"]], sorted(e.path for e in trans._errors))
 
     def test_unexpected_object_properties(self):
         schema = {"type": "object",
                   "properties": {"good_property": {"type": "string"}}}
         data = {"good_property": "expected data",
                 "bad_property": "unexpected data"}
-        success, transformed_data, _, _ = transform_recur(data, schema, NO_INTEGER_DATETIME_PARSING, [], [])
-        self.assertEqual(True, success)
-        self.assertEqual({"good_property": "expected data"}, transformed_data)
+        trans = Transformer()
+        success, transformed_data = trans.transform_recur(data, schema, [])
+        self.assertTrue(success)
+        self.assertDictEqual(data, transformed_data)
